<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>View</name>
    <message>
        <location filename="../View.js" line="+64"/>
        <source>View Tools</source>
        <translation>Nástroje Zobrazovania</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show view tools</source>
        <translation>Zobraziť nástroje zobazovania</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;View</source>
        <translation>&amp;Zobraziť</translation>
    </message>
</context>
</TS>
